@@ -47,9 +47,7 @@ EffectWatcher *ThemePrivate::s_backgroundContrastEffectWatcher = nullptr;
 #endif
 
 ThemePrivate *ThemePrivate::globalTheme = nullptr;
-QAtomicInt ThemePrivate::globalThemeRefCount = QAtomicInt();
 QHash<QString, ThemePrivate *> ThemePrivate::themes = QHash<QString, ThemePrivate *>();
-QHash<QString, QAtomicInt> ThemePrivate::themesRefCount = QHash<QString, QAtomicInt>();
 
 ThemePrivate::ThemePrivate(QObject *parent)
     : QObject(parent),
@@ -75,6 +73,7 @@ ThemePrivate::ThemePrivate(QObject *parent)
       backgroundIntensity(qQNaN()),
       backgroundSaturation(qQNaN()),
       backgroundContrastEnabled(true),
+      blurBehindEnabled(true),
       apiMajor(1),
       apiMinor(0),
       apiRevision(0)
@@ -736,6 +735,17 @@ void ThemePrivate::processContrastSettings(KConfigBase *metadata)
     }
 }
 
+void ThemePrivate::processBlurBehindSettings(KConfigBase *metadata)
+{
+    KConfigGroup cg;
+    if (metadata->hasGroup("BlurBehindEffect")) {
+        cg = KConfigGroup(metadata, "BlurBehindEffect");
+        blurBehindEnabled = cg.readEntry("enabled", true);
+    } else {
+        blurBehindEnabled = true;
+    }
+}
+
 void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings, bool emitChanged)
 {
     QString theme = tempThemeName;
@@ -800,6 +810,7 @@ void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings
         pluginInfo = KPluginInfo(metadataPath);
 
         processContrastSettings(&metadata);
+        processBlurBehindSettings(&metadata);
 
         processWallpaperSettings(&metadata);
 
